@@ -176,10 +176,12 @@ EXAMPLE_IMAGES = {
     "moon.png": "Image showing a portion of the surface of the moon",
     "page.png": "A scanned page of text",
     "text.png": "A photograph of handdrawn text",
+    "bacterial_colony.tif": "Multi-page TIFF image of a bacterial colony",
     "chelsea.zip": "The chelsea.png in a zipfile (for testing)",
     "chelsea.bsdf": "The chelsea.png in a BSDF file(for testing)",
     "newtonscradle.gif": "Animated GIF of a newton's cradle",
     "cockatoo.mp4": "Video file of a cockatoo",
+    "cockatoo_yuv420.mp4": "Video file of a cockatoo with yuv420 pixel format",
     "stent.npz": "Volumetric image showing a stented abdominal aorta",
     "meadow_cube.jpg": "A cubemap image of a meadow, e.g. to render a skybox.",
 }
@@ -697,6 +699,9 @@ class SeekableFileObject:
 
         return res
 
+    def readline(self):
+        yield from self._file.readline()
+
     def tell(self):
         return self._i
 
