@@ -1,50 +1,48 @@
 # -*- coding: utf-8 -*-
 # imageio is distributed under the terms of the (new) BSD License.
 
-""" Plugin that wraps the freeimage lib. The wrapper for Freeimage is
-part of the core of imageio, but it's functionality is exposed via
-the plugin system (therefore this plugin is very thin).
-"""
+"""Read/Write images using FreeImage.
 
-from __future__ import absolute_import, print_function, division
+Backend Library: `FreeImage <https://freeimage.sourceforge.io/>`_
+
+.. note::
+    To use this plugin you have to install its backend::
+
+        imageio_download_bin freeimage
+
+    or you can download the backend using the function::
+
+        imageio.plugins.freeimage.download()
+
+Each Freeimage format has the ``flags`` keyword argument. See the `Freeimage
+documentation <https://freeimage.sourceforge.io/>`_ for more information.
+
+Parameters
+----------
+flags : int
+    A freeimage-specific option. In most cases we provide explicit
+    parameters for influencing image reading.
+
+"""
 
 import numpy as np
 
-from .. import formats
 from ..core import Format, image_as_uint
-from ._freeimage import fi, download, IO_FLAGS, FNAME_PER_PLATFORM  # noqa
-
+from ..core.request import RETURN_BYTES
+from ._freeimage import FNAME_PER_PLATFORM, IO_FLAGS, download, fi  # noqa
 
 # todo: support files with only meta data
 
 
 class FreeimageFormat(Format):
-    """ This is the default format used for FreeImage. Each Freeimage
-    format has the 'flags' keyword argument. See the Freeimage
-    documentation for more information.
-
-    The freeimage plugin requires a `freeimage` binary. If this binary
-    not available on the system, it can be downloaded manually from
-    <https://github.com/imageio/imageio-binaries> by either
-    
-    - the command line script ``imageio_download_bin freeimage``
-    - the Python method ``imageio.plugins.freeimage.download()``
-
-    Parameters for reading
-    ----------------------
-    flags : int
-        A freeimage-specific option. In most cases we provide explicit
-        parameters for influencing image reading.
-    
-    Parameters for saving
-    ----------------------
-    flags : int
-        A freeimage-specific option. In most cases we provide explicit
-        parameters for influencing image saving.
-    """
+    """See :mod:`imageio.plugins.freeimage`"""
 
     _modes = "i"
 
+    def __init__(self, name, description, extensions=None, modes=None, *, fif=None):
+        super().__init__(name, description, extensions=extensions, modes=modes)
+        self._fif = fif
+
     @property
     def fif(self):
         return self._fif  # Set when format is created
@@ -59,6 +57,10 @@ class FreeimageFormat(Format):
                     request._fif = -1
             if request._fif == self.fif:
                 return True
+            elif request._fif == 7 and self.fif == 14:
+                # PPM gets identified as PBM and PPM can read PBM
+                # see: https://github.com/imageio/imageio/issues/677
+                return True
 
     def _can_write(self, request):
         # Ask freeimage, because we are not aware of all formats
@@ -66,8 +68,11 @@ class FreeimageFormat(Format):
             if not hasattr(request, "_fif"):
                 try:
                     request._fif = fi.getFIF(request.filename, "w")
-                except Exception:  # pragma: no cover
-                    request._fif = -1
+                except ValueError:  # pragma: no cover
+                    if request.raw_uri == RETURN_BYTES:
+                        request._fif = self.fif
+                    else:
+                        request._fif = -1
             if request._fif is self.fif:
                 return True
 
@@ -137,21 +142,21 @@ class FreeimageFormat(Format):
             self._meta = meta
 
 
-## Special plugins
+# Special plugins
 
 # todo: there is also FIF_LOAD_NOPIXELS,
 # but perhaps that should be used with get_meta_data.
 
 
 class FreeimageBmpFormat(FreeimageFormat):
-    """ A BMP format based on the Freeimage library.
-    
+    """A BMP format based on the Freeimage library.
+
     This format supports grayscale, RGB and RGBA images.
 
     The freeimage plugin requires a `freeimage` binary. If this binary
     not available on the system, it can be downloaded manually from
     <https://github.com/imageio/imageio-binaries> by either
-    
+
     - the command line script ``imageio_download_bin freeimage``
     - the Python method ``imageio.plugins.freeimage.download()``
 
@@ -161,7 +166,7 @@ class FreeimageBmpFormat(FreeimageFormat):
         Whether to compress the bitmap using RLE when saving. Default False.
         It seems this does not always work, but who cares, you should use
         PNG anyway.
-    
+
     """
 
     class Writer(FreeimageFormat.Writer):
@@ -181,14 +186,14 @@ class FreeimageBmpFormat(FreeimageFormat):
 
 
 class FreeimagePngFormat(FreeimageFormat):
-    """ A PNG format based on the Freeimage library.
-    
+    """A PNG format based on the Freeimage library.
+
     This format supports grayscale, RGB and RGBA images.
 
     The freeimage plugin requires a `freeimage` binary. If this binary
     not available on the system, it can be downloaded manually from
     <https://github.com/imageio/imageio-binaries> by either
-    
+
     - the command line script ``imageio_download_bin freeimage``
     - the Python method ``imageio.plugins.freeimage.download()``
 
@@ -196,7 +201,7 @@ class FreeimagePngFormat(FreeimageFormat):
     ----------------------
     ignoregamma : bool
         Avoid gamma correction. Default True.
-    
+
     Parameters for saving
     ---------------------
     compression : {0, 1, 6, 9}
@@ -262,14 +267,14 @@ class FreeimagePngFormat(FreeimageFormat):
 
 
 class FreeimageJpegFormat(FreeimageFormat):
-    """ A JPEG format based on the Freeimage library.
-    
+    """A JPEG format based on the Freeimage library.
+
     This format supports grayscale and RGB images.
 
     The freeimage plugin requires a `freeimage` binary. If this binary
     not available on the system, it can be downloaded manually from
     <https://github.com/imageio/imageio-binaries> by either
-    
+
     - the command line script ``imageio_download_bin freeimage``
     - the Python method ``imageio.plugins.freeimage.download()``
 
@@ -280,9 +285,9 @@ class FreeimageJpegFormat(FreeimageFormat):
         Default True. If 2 is given, do the rotation in Python instead
         of freeimage.
     quickread : bool
-        Read the image more quickly, at the expense of quality. 
+        Read the image more quickly, at the expense of quality.
         Default False.
-    
+
     Parameters for saving
     ---------------------
     quality : scalar
@@ -296,7 +301,7 @@ class FreeimageJpegFormat(FreeimageFormat):
         few percent of file size). Default False.
     baseline : bool
         Save basic JPEG, without metadata or any markers. Default False.
-    
+
     """
 
     class Reader(FreeimageFormat.Reader):
@@ -316,7 +321,7 @@ class FreeimageJpegFormat(FreeimageFormat):
             return im, meta
 
         def _rotate(self, im, meta):
-            """ Use Orientation information from EXIF meta data to 
+            """Use Orientation information from EXIF meta data to
             orient the image correctly. Freeimage is also supposed to
             support that, and I am pretty sure it once did, but now it
             does not, so let's just do it in Python.
@@ -370,115 +375,30 @@ class FreeimageJpegFormat(FreeimageFormat):
             return FreeimageFormat.Writer._append_data(self, im, meta)
 
 
-## Create the formats
+class FreeimagePnmFormat(FreeimageFormat):
+    """A PNM format based on the Freeimage library.
 
-SPECIAL_CLASSES = {
-    "jpeg": FreeimageJpegFormat,
-    "png": FreeimagePngFormat,
-    "bmp": FreeimageBmpFormat,
-    "gif": None,  # defined in freeimagemulti
-    "ico": None,  # defined in freeimagemulti
-    "mng": None,  # defined in freeimagemulti
-}
+    This format supports single bit (PBM), grayscale (PGM) and RGB (PPM)
+    images, even with ASCII or binary coding.
 
-# rename TIFF to make way for the tiffile plugin
-NAME_MAP = {"TIFF": "FI_TIFF"}
+    The freeimage plugin requires a `freeimage` binary. If this binary
+    not available on the system, it can be downloaded manually from
+    <https://github.com/imageio/imageio-binaries> by either
 
-# This is a dump of supported FreeImage formats on Linux fi verion 3.16.0
-# > imageio.plugins.freeimage.create_freeimage_formats()
-# > for i in sorted(imageio.plugins.freeimage.fiformats): print('%r,' % (i, ))
-fiformats = [
-    ("BMP", 0, "Windows or OS/2 Bitmap", "bmp"),
-    ("CUT", 21, "Dr. Halo", "cut"),
-    ("DDS", 24, "DirectX Surface", "dds"),
-    ("EXR", 29, "ILM OpenEXR", "exr"),
-    ("G3", 27, "Raw fax format CCITT G.3", "g3"),
-    ("GIF", 25, "Graphics Interchange Format", "gif"),
-    ("HDR", 26, "High Dynamic Range Image", "hdr"),
-    ("ICO", 1, "Windows Icon", "ico"),
-    ("IFF", 5, "IFF Interleaved Bitmap", "iff,lbm"),
-    ("J2K", 30, "JPEG-2000 codestream", "j2k,j2c"),
-    ("JNG", 3, "JPEG Network Graphics", "jng"),
-    ("JP2", 31, "JPEG-2000 File Format", "jp2"),
-    ("JPEG", 2, "JPEG - JFIF Compliant", "jpg,jif,jpeg,jpe"),
-    ("JPEG-XR", 36, "JPEG XR image format", "jxr,wdp,hdp"),
-    ("KOALA", 4, "C64 Koala Graphics", "koa"),
-    ("MNG", 6, "Multiple-image Network Graphics", "mng"),
-    ("PBM", 7, "Portable Bitmap (ASCII)", "pbm"),
-    ("PBMRAW", 8, "Portable Bitmap (RAW)", "pbm"),
-    ("PCD", 9, "Kodak PhotoCD", "pcd"),
-    ("PCX", 10, "Zsoft Paintbrush", "pcx"),
-    ("PFM", 32, "Portable floatmap", "pfm"),
-    ("PGM", 11, "Portable Greymap (ASCII)", "pgm"),
-    ("PGMRAW", 12, "Portable Greymap (RAW)", "pgm"),
-    ("PICT", 33, "Macintosh PICT", "pct,pict,pic"),
-    ("PNG", 13, "Portable Network Graphics", "png"),
-    ("PPM", 14, "Portable Pixelmap (ASCII)", "ppm"),
-    ("PPMRAW", 15, "Portable Pixelmap (RAW)", "ppm"),
-    ("PSD", 20, "Adobe Photoshop", "psd"),
-    ("RAS", 16, "Sun Raster Image", "ras"),
-    (
-        "RAW",
-        34,
-        "RAW camera image",
-        "3fr,arw,bay,bmq,cap,cine,cr2,crw,cs1,dc2,"
-        "dcr,drf,dsc,dng,erf,fff,ia,iiq,k25,kc2,kdc,mdc,mef,mos,mrw,nef,nrw,orf,"
-        "pef,ptx,pxn,qtk,raf,raw,rdc,rw2,rwl,rwz,sr2,srf,srw,sti",
-    ),
-    ("SGI", 28, "SGI Image Format", "sgi,rgb,rgba,bw"),
-    ("TARGA", 17, "Truevision Targa", "tga,targa"),
-    ("TIFF", 18, "Tagged Image File Format", "tif,tiff"),
-    ("WBMP", 19, "Wireless Bitmap", "wap,wbmp,wbm"),
-    ("WebP", 35, "Google WebP image format", "webp"),
-    ("XBM", 22, "X11 Bitmap Format", "xbm"),
-    ("XPM", 23, "X11 Pixmap Format", "xpm"),
-]
+    - the command line script ``imageio_download_bin freeimage``
+    - the Python method ``imageio.plugins.freeimage.download()``
 
-
-def _create_predefined_freeimage_formats():
-
-    for name, i, des, ext in fiformats:
-        # name = NAME_MAP.get(name, name)
-        # Get class for format
-        FormatClass = SPECIAL_CLASSES.get(name.lower(), FreeimageFormat)
-        if FormatClass:
-            # Create Format and add
-            format = FormatClass(name + "-FI", des, ext, FormatClass._modes)
-            format._fif = i
-            formats.add_format(format)
-
-
-def create_freeimage_formats():
-    """ By default, imageio registers a list of predefined formats
-    that freeimage can handle. If your version of imageio can handle
-    more formats, you can call this function to register them.
+    Parameters for saving
+    ---------------------
+    use_ascii : bool
+        Save with ASCII coding. Default True.
     """
-    fiformats[:] = []
 
-    # Freeimage available?
-    if fi is None:  # pragma: no cover
-        return
-
-    # Init
-    lib = fi._lib
-
-    # Create formats
-    for i in range(lib.FreeImage_GetFIFCount()):
-        if lib.FreeImage_IsPluginEnabled(i):
-            # Get info
-            name = lib.FreeImage_GetFormatFromFIF(i).decode("ascii")
-            des = lib.FreeImage_GetFIFDescription(i).decode("ascii")
-            ext = lib.FreeImage_GetFIFExtensionList(i).decode("ascii")
-            fiformats.append((name, i, des, ext))
-            # name = NAME_MAP.get(name, name)
-            # Get class for format
-            FormatClass = SPECIAL_CLASSES.get(name.lower(), FreeimageFormat)
-            if not FormatClass:
-                continue
-            # Create Format and add
-            format = FormatClass(name + "-FI", des, ext, FormatClass._modes)
-            format._fif = i
-            formats.add_format(format, overwrite=True)
-
-
-_create_predefined_freeimage_formats()
+    class Writer(FreeimageFormat.Writer):
+        def _open(self, flags=0, use_ascii=True):
+            # Build flags from kwargs
+            flags = int(flags)
+            if use_ascii:
+                flags |= IO_FLAGS.PNM_SAVE_ASCII
+            # Act as usual, but with modified flags
+            return FreeimageFormat.Writer._open(self, flags)
