@@ -260,14 +260,14 @@ def test_gif_gray(test_images, tmp_path):
     )
 
 
-def test_gif_fps_error(test_images, tmp_path):
+def test_gif_fps_warning(test_images, tmp_path):
     im = iio.imread(
         test_images / "newtonscradle.gif",
         plugin="pillow",
         mode="L",
     )
 
-    with pytest.raises(TypeError):
+    with pytest.warns(DeprecationWarning):
         iio.imwrite(
             tmp_path / "test.gif",
             im[..., 0],
@@ -360,6 +360,17 @@ def test_gif_list_write(test_images, tmp_path):
     assert im2.shape == (24, 30, 3)
 
 
+@pytest.mark.needs_internet
+def test_gif_first_p_frame():
+    # Bugfix: https://github.com/imageio/imageio/issues/1030
+    im = iio.imread(
+        "https://upload.wikimedia.org/wikipedia/commons/d/d3/Newtons_cradle_animation_book_2.gif",
+        plugin="pillow",
+        index=None,
+    )
+    assert im.shape == (36, 360, 480, 3)
+
+
 def test_legacy_exif_orientation(test_images, tmp_path):
     from PIL.Image import Exif
 
@@ -694,3 +705,30 @@ def test_writable_output():
 
     frame = iio.imread(buffer, writeable_output=False, plugin="pillow")
     assert not frame.flags["WRITEABLE"]
+
+
+@pytest.mark.needs_internet
+def test_heif_remote():
+    pytest.importorskip("pillow_heif")
+    url = "http://github.com/tigranbs/test-heic-images/raw/master/image4.heic"
+    im = iio.imread(url, plugin="pillow")
+    assert im.shape == (476, 700, 4)
+
+
+@pytest.mark.needs_internet
+def test_avif_remote():
+    pytest.importorskip("pillow_heif")
+
+    url = "https://github.com/link-u/avif-sample-images/raw/master/fox.profile0.10bpc.yuv420.avif"
+    im = iio.imread(url, plugin="pillow")
+    assert im.shape == (800, 1204, 3)
+
+
+@pytest.mark.needs_internet
+def test_webp_remote():
+    # this is a regression test for
+    # https://github.com/imageio/imageio/issues/1065
+    # the image in the issue is actually a webp image
+    url = "https://github.com/python-pillow/Pillow/raw/main/Tests/images/hopper_orientation_2.webp"
+    im = iio.imread(url, plugin="pillow")
+    assert im.shape == (128, 128, 3)
